@@ -15,7 +15,7 @@
 #' default
 #' @param dist.arg a list or vector of inputs for the distance metric met; NULL by default
 #' @param m the number of plots in the lineup; m = 20 by default
-#' @return lineup has the data used for the caulations
+#' @return lineup has the data used for the calculations
 #' @return null_values contains new null samples from which to compare nulls in lineup
 #' @return diff difference in distance between nulls and actual data and that of the null
 #' that is most different from other nulls. A negative value means that the actual data
@@ -27,27 +27,33 @@
 #' # Each of these examples uses a small number of nulls (m=8), and a small number of
 #' # repeated sampling from the null distribution (repl=100), to make it faster to run.
 #' # In your own examples you should think about increasing each of these, at least to the defaults.
+#' \dontrun{
 #' if (require('dplyr')) {
 #'   d <- lineup(null_permute('mpg'), mtcars, pos = 1)
 #'   dd <- distmet(d, var = c('mpg', 'wt'),
 #'     'reg_dist', null_permute('mpg'), pos = 1, repl = 100, m = 8)
 #'   distplot(dd, m=8)
 #' }
+#' }
 #'
+#' \dontrun{
 #' d <- lineup(null_permute('mpg'), mtcars, pos=4, n=8)
-#' qplot(mpg, wt, data = d, geom = 'point') + facet_wrap(~ .sample, ncol=4)
+#' library(ggplot2)
+#' ggplot(d, aes(mpg, wt)) + geom_point() + facet_wrap(~ .sample, ncol=4)
 #' if (require('dplyr')) {
 #'   dd <- distmet(d, var = c('mpg', 'wt'), 'bin_dist', null_permute('mpg'),
 #'     pos = 4, repl = 100, dist.arg = list(lineup.dat = d, X.bin = 5,
 #'     Y.bin = 5), m = 8)
 #'   distplot(dd, m=8)
 #' }
+#' }
 #'
 #' # Example using bin_dist
 #' \dontrun{
 #' if (require('dplyr')) {
 #'   d <- lineup(null_permute('mpg'), mtcars, pos = 1)
-#'   qplot(mpg, wt, data=d, geom='point') + facet_wrap(~ .sample, ncol=5)
+#'   library(ggplot2)
+#'   ggplot(d, aes(mpg, wt)) + geom_point() + facet_wrap(~ .sample, ncol=5)
 #'   dd <- distmet(d, var = c('mpg', 'wt'),
 #'     'bin_dist', null_permute('mpg'), pos = 1, repl = 500,
 #'     dist.arg = list(lineup.dat = d, X.bin = 5, Y.bin = 5))
@@ -60,8 +66,7 @@
 #' mod <- lm(wt ~ mpg, data = mtcars)
 #' resid.dat <- data.frame(residual = mod$resid)
 #' d <- lineup(null_dist('residual', dist = 'normal'), resid.dat, pos=19)
-#' qplot(residual, data = d, geom = 'histogram', binwidth = 0.25) +
-#'   facet_wrap(~ .sample, ncol=5)
+#' ggplot(d, aes(residual)) + geom_histogram(binwidth = 0.25) + facet_wrap(~ .sample, ncol=5)
 #' if (require('dplyr')) {
 #'   dd <- distmet(d, var = 'residual', 'uni_dist', null_dist('residual',
 #'     dist = 'normal'), pos = 19, repl = 500)
@@ -102,22 +107,39 @@ null_gen <- function(lineup.dat, null, met, method, m, dist.arg){
 #' @param dat output from \code{\link{distmet}}
 #' @param m the number of plots in the lineup; m = 20 by default
 #' @export
+#' @importFrom stats density
 #' @examples
+#' \dontrun{
 #' if (require('dplyr')) {
 #'   d <- lineup(null_permute('mpg'), mtcars, pos = 1)
-#'   qplot(mpg, wt, data=d) + facet_wrap(~.sample)
+#'   library(ggplot2)
+#'   ggplot(d, aes(mpg, wt)) + geom_point() + facet_wrap(~.sample)
 #'   distplot(distmet(d, var = c('mpg', 'wt'), 'reg_dist', null_permute('mpg'),
 #'     pos = 1, repl = 100, m = 8), m = 8)
 #' }
+#' }
 distplot <- function(dat, m = 20) {
-    p <- with(dat, ggplot2::qplot(null_values, geom = "density", fill = I("grey80"), colour = I("grey80"),
-        xlab = "Permutation distribution", ylab = "") + ggplot2::geom_segment(aes(x = lineup$mean.dist[lineup$plotno !=
-        pos], xend = lineup$mean.dist[lineup$plotno != pos], y = rep(0.01 * min(density(null_values)$y),
-        (m - 1)), yend = rep(0.05 * max(density(null_values)$y), (m - 1))), size = 1, alpha = I(0.7)) +
-        ggplot2::geom_segment(aes(x = lineup$mean.dist[lineup$plotno == pos], xend = lineup$mean.dist[lineup$plotno ==
-            pos], y = 0.01 * min(density(null_values)$y), yend = 0.1 * max(density(null_values)$y)),
-            colour = "darkorange", size = 1) + ggplot2::geom_text(data = lineup, y = -0.03 * max(density(null_values)$y),
-        size = 2.5, aes(x = mean.dist, label = plotno)) + ggplot2::ylim(c(-0.04 * max(density(null_values)$y),
-        max(density(null_values)$y) + 0.1)))
+  null_values <- NULL
+  mean.dist <- NULL
+  y <- yend <- NULL
+  true <- NULL
+  plotno <- NULL
+
+    null <- data.frame(null_values=dat$null_values)
+    lineupvals <- dat$lineup
+    lineupvals$true <- ifelse(lineupvals$plotno == dat$pos, "true", "null")
+    lineupvals$y <- 0.01 * min(density(null$null_values)$y)
+    lineupvals$yend <- 0.05 * max(density(null$null_values)$y)
+
+    p <- ggplot2::ggplot(null, ggplot2::aes(x=null_values)) +
+         ggplot2::geom_density(fill = I("grey80"), colour = I("grey80")) +
+              xlab("Permutation distribution") + ylab("")
+    p <- p + ggplot2::geom_segment(data=lineupvals, ggplot2::aes(x=mean.dist, xend=mean.dist,
+                            y=y, yend=yend, colour=true), alpha=0.8)
+    p <- p + ggplot2::geom_text(data=lineupvals,
+                              ggplot2::aes(x = mean.dist, y=0, label = plotno, colour=true), vjust="top")
+    p <- p + ggplot2::scale_colour_manual(values=c("true"="darkorange","null"="grey50"))
+    p <- p + ggplot2::theme(legend.position="none")
+
     return(p)
 }
