@@ -6,7 +6,6 @@
 #'
 #' @param var variable to model as a time series
 #' @param modelfn method for simulating from ts model.
-#' @param ... other arguments passed onto \code{modelfn}.
 #' @return a function that given \code{data} generates a null data set.
 #'   For use with \code{\link{lineup}} or \code{\link{rorschach}}
 #' @export
@@ -15,7 +14,8 @@
 #' @importFrom tibble as_data_frame
 #' @examples
 #' require(forecast)
-#' require(tidyverse)
+#' require(ggplot2)
+#' require(dplyr)
 #' data(aud)
 #' l <- lineup(null_ts("rate", auto.arima), aud)
 #' ggplot(l, aes(x=date, y=rate)) + geom_line() +
@@ -34,8 +34,7 @@ null_ts <- function(var, modelfn) {
     model_fit <- ts %>%
       modelfn
     x <- simulate(model_fit, future=FALSE)
-    x <- as_data_frame(x)
-    df[[var]] <- as.vector(x$x)
+    df[[var]] <- as.vector(x)
     df
   }
 }
